==> moodle-1.4.3-pgsql.tgz: moodle/lang/de/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.4 aiming-for-beta-soon (2004082200)


$string['about'] = 'ber diesen Editor';
$string['absbottom'] = 'Unten ausrichten';
$string['middle'] = 'Position in der Mitte';
$string['address'] = 'Anschrift';
$string['alignment'] = 'Anordnung';
$string['alternatetext'] = 'Alternativer Text';
$string['anchorhelp'] = 'Hiermit erstellen Sie nur einen Anker. Zustzlich mssen Sie einen Link manuell erstellen.';
$string['anchorname'] = 'Name des Ankers';
$string['anchors'] = 'Anker';
$string['baseline'] = 'Grundlinie';
$string['bold'] = 'Fett';
$string['borderthickness'] = 'Dicke der Rnder';
$string['bottom'] = 'Ende';
$string['browse'] = 'Surchsuchen';
$string['cancel'] = 'Abbrechen';
$string['cellpadding'] = 'Zelle auffllen';
$string['cellspacing'] = 'Zellabstand';
$string['choosechar'] = 'Zeichen auswhlen';
$string['chooseicon'] = 'Whlen Sie ein Icon aus, das eingefgt werden soll';
$string['close'] = 'Schlieen';
$string['cols'] = 'Reihen';
$string['copy'] = 'Die Auswahl kopieren';
$string['createanchor'] = 'Anker erstellen';
$string['createfolder'] = 'Ordner erstellen';
$string['createlink'] = 'Einen Link einfgen';
$string['cut'] = 'Markierung ausschneiden';
$string['delete'] = 'Lschen';
$string['filebrowser'] = 'Dateienbrowser';
$string['forecolor'] = 'Farbe der Zeichen';
$string['fullscreen'] = 'Groe Bildschirmanzeige';
$string['heading'] = 'Kopfbereich';
$string['height'] = 'Hhe';
$string['hilitecolor'] = 'Farbe des Hintergrundes';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Horizontale Anordnung';
$string['htmlmode'] = 'Umschalten auf HTML- Code';
$string['imageurl'] = 'Abbild URL';
$string['indent'] = 'Einzug vergrern';
$string['insertchar'] = 'Spezielles Zeichen einfgen';
$string['insertimage'] = 'Bild einfgen';
$string['insertlink'] = 'Link einfgen';
$string['insertsmile'] = 'Smilie einfgen';
$string['inserttable'] = 'Tabelle einfgen';
$string['italic'] = 'Kursivschrift';
$string['justifycenter'] = 'Zentriert';
$string['justifyfull'] = 'Blocksatz';
$string['justifyleft'] = 'Linksbndig';
$string['justifyright'] = 'Rechtsbndig';
$string['layout'] = 'Layout';
$string['left'] = 'Links';
$string['lefttoright'] = 'Schreibrichtung von links nach rechts';
$string['linkproperties'] = 'Linkeigenschaften';
$string['linktarget'] = 'Ziel';
$string['linktargetblank'] = 'Neues Fenster';
$string['linktargetnone'] = 'Keine';
$string['linktargetother'] = 'Andere (ausserhalb der Reihe)';
$string['linktargetself'] = 'Gleicher Frame';
$string['linktargettop'] = 'Gleiches Fenster';
$string['linktitle'] = 'Titel';
$string['linkurl'] = 'URL';
$string['middle'] = 'Mitte';
$string['minimize'] = 'Fenster verkleinern';
$string['move'] = 'Bewegen';
$string['normal'] = 'Normal';
$string['notimage'] = 'Die ausgewhlte Datei ist kein Bild. Bitte whlen Sie eine Bilddatei aus.';
$string['notset'] = 'Nicht gesetzt';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Liste sortiert';
$string['outdent'] = 'Einzug verkleinern';
$string['paste'] = 'Einfgen aus dem Speicher';
$string['path'] = 'Pfad';
$string['percent'] = 'Prozent';
$string['pixels'] = 'Pixel';
$string['popupeditor'] = 'Editor vergrern';
$string['preformatted'] = 'Vorformatiert';
$string['preview'] = 'Vorschau';
$string['properties'] = 'Eigenschaften';
$string['redo'] = 'Zurck zur letzten Aktion';
$string['removelink'] = 'Link entfernen';
$string['rename'] = 'Umbenennen';
$string['right'] = 'Rechts';
$string['righttoleft'] = 'Schreibrichtung von rechts nach links';
$string['rows'] = 'Zeilen';
$string['selectcolor'] = 'Farbe auswhlen';
$string['selection'] = 'Auswahl';
$string['showhelp'] = 'Hilfe zur Verwendung des Editors';
$string['size'] = 'Gre';
$string['spacing'] = 'Abstand';
$string['strikethrough'] = 'Durchgestrichen';
$string['subscript'] = 'Tiefgestellt';
$string['superscript'] = 'Hochgestellt';
$string['textindicator'] = 'Aktuelle Schrift';
$string['textmode'] = 'Sie befinden sich zur Zeit im TEXT- Modus.Benutzen Sie die [<>]- Icon, um zurck in den WYSIWYG- MOdus zu wechseln. ';
$string['texttop'] = 'Einleitungstext';
$string['top'] = 'Anfang';
$string['type'] = 'Typ';
$string['underline'] = 'Unterstrichen';
$string['undo'] = 'Rckgngig';
$string['unorderedlist'] = 'Aufzhlungszeichen';
$string['upload'] = 'Hochladen';
$string['vertical'] = 'Hhe';
$string['width'] = 'Breite';
$string['wordclean'] = 'HTML-Text';
$string['zip'] = 'Zip';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/de/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 ALPHA (2005051500)


$string['about'] = 'ber diesen Editor';
$string['absbottom'] = 'Unten ausrichten';
$string['address'] = 'Adresse';
$string['alertnoselectedtext'] = 'Markieren Sie erst den Text!';
$string['alignment'] = 'Anordnung';
$string['alternatetext'] = 'Alternativer Text';
$string['anchorhelp'] = 'Hiermit erstellen Sie nur einen Anker. Zustzlich mssen Sie einen Link manuell erstellen.';
$string['anchorname'] = 'Name des Ankers';
$string['anchors'] = 'Anker';
$string['baseline'] = 'Grundlinie';
$string['bold'] = 'Fett';
$string['borderthickness'] = 'Dicke der Rnder';
$string['bottom'] = 'Ende';
$string['browse'] = 'Durchsuchen';
$string['cancel'] = 'Abbrechen';
$string['cellpadding'] = 'Zelle auffllen';
$string['cellspacing'] = 'Zellabstand';
$string['choosechar'] = 'Zeichen auswhlen';
$string['chooseicon'] = 'Whlen Sie ein Icon aus, das eingefgt werden soll';
$string['close'] = 'Schlieen';
$string['closeafterreplace'] = 'Nach dem Ersetzen schlieen';
$string['cols'] = 'Reihen';
$string['copy'] = 'Die Auswahl kopieren';
$string['createanchor'] = 'Anker erstellen';
$string['createfolder'] = 'Ordner erstellen';
$string['createlink'] = 'Einen Link einfgen';
$string['cut'] = 'Markierung ausschneiden';
$string['cutpastemozilla'] = 'Leider knnen Sie mit diesem Editor	die gewohnten Tastatur-Shortcuts zum Einfgen von Texten nicht nutzen. Hintergrund ist eine Sicherheitsfunktion in einigen Versionen von Mozilla und Firefox.U<br /><br />Sie haben drei Mglichkeiten, die Sie probieren knnen: <br /> (1) An Stelle von Strg-v, verwenden Sie SHIFT-Einfg <br /> (2) Nutzen Sie das Menu mit Bearbeiten -> Einfgen <br /> (3) Verndern Sie die Einstellungen des Browsers in der Datei user.js. <br /><br />Mit dem  \'OK\' Button finden Sie weitere Informationen, oder \'Abbrechen\', um zum Browser zurckzugehen.';
$string['delete'] = 'Lschen';
$string['filebrowser'] = 'Dateibrowser';
$string['findwhat'] = 'Finden';
$string['fontname'] = 'Schriftname';
$string['fontsize'] = 'Schriftgre';
$string['forecolor'] = 'Farbe der Zeichen';
$string['formatblock'] = 'Format';
$string['fullscreen'] = 'Groe Bildschirmanzeige';
$string['heading'] = 'Kopfbereich';
$string['height'] = 'Hhe (Pixel)';
$string['hilitecolor'] = 'Farbe des Hintergrundes';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Horizontale Anordnung';
$string['htmlmode'] = 'Umschalten auf HTML- Code';
$string['imageurl'] = 'Abbild URL';
$string['indent'] = 'Einzug vergrern';
$string['insertchar'] = 'Spezielles Zeichen einfgen';
$string['insertimage'] = 'Bild einfgen';
$string['insertlink'] = 'Link einfgen';
$string['insertsmile'] = 'Smiley einfgen';
$string['inserttable'] = 'Tabelle einfgen';
$string['italic'] = 'Kursivschrift';
$string['itemsreplaced'] = 'Werte ersetzt!';
$string['justifycenter'] = 'Zentriert';
$string['justifyfull'] = 'Blocksatz';
$string['justifyleft'] = 'Linksbndig';
$string['justifyright'] = 'Rechtsbndig';
$string['layout'] = 'Layout';
$string['left'] = 'Links';
$string['lefttoright'] = 'Schreibrichtung von links nach rechts';
$string['linkproperties'] = 'Linkeigenschaften';
$string['linktarget'] = 'Ziel';
$string['linktargetblank'] = 'Neues Fenster';
$string['linktargetnone'] = 'Keine';
$string['linktargetother'] = 'Andere (ausserhalb der Reihe)';
$string['linktargetself'] = 'Gleicher Frame';
$string['linktargettop'] = 'Gleiches Fenster';
$string['linktitle'] = 'Titel';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Gro-/Kleinschreibung vergleichen';
$string['middle'] = 'Mitte';
$string['minimize'] = 'Fenster verkleinern';
$string['move'] = 'Bewegen';
$string['nolink'] = 'Keine automatische Verlinkung';
$string['normal'] = 'Normal';
$string['notimage'] = 'Die ausgewhlte Datei ist kein Bild. Bitte whlen Sie eine Bilddatei aus.';
$string['notset'] = 'Nicht gesetzt';
$string['ok'] = 'OK';
$string['options'] = 'Optionen';
$string['orderedlist'] = 'Liste sortiert';
$string['outdent'] = 'Einzug verkleinern';
$string['paste'] = 'Einfgen aus dem Speicher';
$string['path'] = 'Pfad';
$string['percent'] = 'Prozent';
$string['pixels'] = 'Pixel';
$string['popupeditor'] = 'Editor vergrern';
$string['preformatted'] = 'Vorformatiert';
$string['preview'] = 'Vorschau';
$string['properties'] = 'Eigenschaften';
$string['redo'] = 'Zurck zur letzten Aktion';
$string['regularexpressions'] = 'Regulre Ausdrcke verwenden';
$string['removelink'] = 'Link entfernen';
$string['rename'] = 'Umbenennen';
$string['replaceall'] = 'Alle ersetzen';
$string['replacewith'] = 'Ersetzen';
$string['right'] = 'Rechts';
$string['righttoleft'] = 'Schreibrichtung von rechts nach links';
$string['rows'] = 'Zeilen';
$string['searchandreplace'] = 'Suchen und ersetzen';
$string['searchnotfound'] = 'Suchbegriff nicht gefunden!';
$string['selectcolor'] = 'Farbe auswhlen';
$string['selection'] = 'Auswahl';
$string['showhelp'] = 'Hilfe zur Verwendung des Editors';
$string['size'] = 'Gre';
$string['spacing'] = 'Abstand';
$string['strikethrough'] = 'Durchgestrichen';
$string['subscript'] = 'Tiefgestellt';
$string['superscript'] = 'Hochgestellt';
$string['textindicator'] = 'Aktuelle Schrift';
$string['textmode'] = 'Sie befinden sich zur Zeit im TEXT- Modus. Benutzen Sie die [<>]- Icon, um zurck in den WYSIWYG- MOdus zu wechseln. ';
$string['texttop'] = 'Einleitungstext';
$string['top'] = 'Anfang';
$string['type'] = 'Typ';
$string['underline'] = 'Unterstrichen';
$string['undo'] = 'Rckgngig';
$string['unorderedlist'] = 'Aufzhlungszeichen';
$string['upload'] = 'Hochladen';
$string['vertical'] = 'Vertikal';
$string['width'] = 'Breite (Pixel)';
$string['wordclean'] = 'Word-Formatierung umwandeln (HTML)';
$string['zip'] = 'Zip';

?>
